[![python](https://img.shields.io/badge/python-3.7-g.svg)]()
[![Documentation Status](https://readthedocs.org/projects/tom-pittgoogle/badge/?version=latest)](https://tom-pittgoogle.readthedocs.io/en/latest/?badge=latest)

# Pitt-Google integration with TOM Toolkit

Please read the docs at [https://tom-pittgoogle.readthedocs.io/en/latest/](https://tom-pittgoogle.readthedocs.io/en/latest/).

Contact Troy Raen with questions or for authentication access (Slack @troyraen on LSSTC or ztf-broker-ops, or email troy.raen@pitt.edu).
